@@ -13,13 +13,15 @@ class RplWhoisHostSupport(RFC1459Support):
         host = data[-2]
 
         meta = {"real_ip_address": ip_addr, "real_hostname": host}
-        self._sync_user(target, meta)
+        await self._sync_user(target, meta)
         if target in self._whois_info:
             self._whois_info[target]["real_ip_address"] = ip_addr
             self._whois_info[target]["real_hostname"] = host
 
     async def whois(self, nickname):
         info = await super().whois(nickname)
+        if info is None:
+            return info
         info.setdefault("real_ip_address", None)
         info.setdefault("real_hostname", None)
         return info
